<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:decimal-format name="pl" decimal-separator="," grouping-separator=" "/>
	<xsl:template match="/">
		<html>
			<head>
				<style>
    
					.header {
						position: relative;
					}
					.header img {
						position: absolute;
						top: 0px;
						right: 0px;
					}
				
					h1, h2, h3, h4, h5 {
						font-family: Geneva, sans-serif;
					}
					h1 {
						text-align: center;
						padding-top: 5px;
						margin-top: 5px;
					}
					h3 {
						padding-left: 2em;
					}
					h4 {
						padding-left: 4em;
					}
					h5 {
						padding-left: 6em;
					}
					
					table {
						border-collapse: collapse;
						font-family: Tahoma, Geneva, sans-serif;
					}
					table tbody td {
						border: 1px solid #838383;
						font-size: 14px;
						padding: 8px;
						background-color: #fbfdfe;
						color: #535353;
					}
					
					table.rejestrppe {
						margin-left: 4em;
					}
					table.pracodawca {
						margin-left: 5em;
					}
					table.okressprawozdawczy {
						margin-left: 6em;
					}
					
					div.okressprawozdawczy {
						color: #001A72;
						font-weight: bold;
						margin-left: 6em;
					}
					div.okressprawozdawczyopis {
						margin-left: 6em;
					}
					
					.xmldata {
						color: #001A72;
						font-weight: bold;
						text-align: right;
					}
	   
				</style>
			</head>
			<body>
				<xsl:for-each select="RaportPPE">
					<div class="header">
						<hr/>
						<img src="https://cebrf.knf.gov.pl/images/FTH/Logo.png" alt="Logo UKNF" width="300px"/>
						<h1>Raport PPE</h1>
						<hr/>
					</div>
					<h2>Nagłówek</h2>
					<xsl:for-each select="Naglowek">
					<table class="naglowek">
						<tbody>
							<tr>
								<td>Rok</td>
								<td class="xmldata">
									<xsl:value-of select="Rok"/>
								</td>
							</tr>
							<xsl:for-each select="InstytucjaZarzadzajaca">
							<tr>
								<td>Identyfikator instytucji zarządzającej</td>
								<td class="xmldata">
									<xsl:value-of select="TFI/@Identyfikator"/>
									<xsl:value-of select="ZU/@Identyfikator"/>
									<xsl:value-of select="PrTE/@Identyfikator"/>
								</td>
							</tr>
							<tr>
								<td>Nazwa instytucji zarządzajacej</td>
								<td class="xmldata">
									<xsl:value-of select="Nazwa"/>
								</td>
							</tr>
							</xsl:for-each>
						</tbody>
					</table>
					<br/>
					<br/>
					</xsl:for-each>
					<h2>Dane</h2>
					<xsl:for-each select="Dane">
						<xsl:for-each select="ProgramPPE">
						<h3>Program PPE</h3>
						<table class="rejestrppe">
							<tbody>
								<tr>
									<td>Rejestr PPE</td>
									<td class="xmldata">
										<xsl:value-of select="@RejestrPPE"/>
									</td>
								</tr>
							</tbody>
						</table>
						<xsl:for-each select="Pracodawca">
							<h5>Pracodawca</h5>
							<table class="pracodawca">
								<tbody>
									<tr>
										<td>REGON</td>
										<td class="xmldata">
											<xsl:value-of select="@REGON"/>
										</td>
									</tr>
									<tr>
										<td>Nazwa</td>
										<td class="xmldata">
											<xsl:value-of select="@Nazwa"/>
										</td>
									</tr>
								</tbody>
							</table>
							<xsl:for-each select="OkresSprawozdawczy">
								<h5>Okres sprawozdawczy</h5>
								<div class="okressprawozdawczy">
									<xsl:value-of select="@Typ"/>
								</div>
								<div class="okressprawozdawczyopis">
									<xsl:choose>
										<xsl:when test="@Typ = 'POLROCZE'">(według stanu na dzień 30 czerwca danego roku kalendarzowego/za pierwsze półrocze)</xsl:when>
										<xsl:when test="@Typ = 'ROK'">(według stanu na dzień 31 grudnia danego roku kalendarzowego/za rok)</xsl:when>
									</xsl:choose>
								</div>
								<table class="okressprawozdawczy">
									<tbody>
										<tr>
											<td>Aktywa</td>
											<td class="xmldata">
												<xsl:value-of select="format-number(Aktywa, '# ##0,00', 'pl')"/>
											</td>
										</tr>
										<tr>
											<td>Liczba uczestników</td>
											<td class="xmldata">
												<xsl:value-of select="LiczbaUczestnikow"/>
											</td>
										</tr>
										<xsl:for-each select="Skladki">
										<xsl:for-each select="Podstawowe">
										<tr>
											<td rowspan="4">Składki</td>
											<td rowspan="2">podstawowe</td>
											<td>wartość wpłat</td>
											<td class="xmldata">
												<xsl:value-of select="format-number(WartoscWplat, '# ##0,00', 'pl')"/>
											</td>
										</tr>
										<tr>
											<td>liczba uczestników</td>
											<td class="xmldata">
												<xsl:value-of select="LiczbaUczestnikow"/>
											</td>
										</tr>
										</xsl:for-each>
										<xsl:for-each select="Dodatkowe">
										<tr>
											<td rowspan="2">dodatkowe</td>
											<td>wartość wpłat</td>
											<td class="xmldata">
												<xsl:value-of select="format-number(WartoscWplat, '# ##0,00', 'pl')"/>
											</td>
										</tr>
										<tr>
											<td>liczba uczestników</td>
											<td class="xmldata">
												<xsl:value-of select="LiczbaUczestnikow"/>
											</td>
										</tr>
										</xsl:for-each>
										</xsl:for-each>
										<xsl:for-each select="Wyplaty">
										<xsl:for-each select="Transferowe">
										<xsl:for-each select="Przyjete">
										<xsl:for-each select="PPE">
										<tr>
											<td rowspan="12">Wypłaty</td>
											<td rowspan="8">transferowe</td>
											<td rowspan="4">przyjęte</td>
											<td rowspan="2">PPE</td>
											<td>wartość wypłat</td>
											<td class="xmldata">
												<xsl:value-of select="format-number(WartoscWyplat, '# ##0,00', 'pl')"/>
											</td>
										</tr>
										<tr>
											<td>liczba osób</td>
											<td class="xmldata">
												<xsl:value-of select="LiczbaOsob"/>
											</td>
										</tr>
										</xsl:for-each>
										<xsl:for-each select="IKE">
										<tr>
											<td rowspan="2">IKE</td>
											<td>wartość wypłat</td>
											<td class="xmldata">
												<xsl:value-of select="format-number(WartoscWyplat, '# ##0,00', 'pl')"/>
											</td>
										</tr>
										<tr>
											<td>liczba osób</td>
											<td class="xmldata">
												<xsl:value-of select="LiczbaOsob"/>
											</td>
										</tr>
										</xsl:for-each>
										</xsl:for-each>
										<xsl:for-each select="Dokonane">
										<xsl:for-each select="PPE">
										<tr>
											<td rowspan="4">dokonane</td>
											<td rowspan="2">PPE</td>
											<td>wartość wypłat</td>
											<td class="xmldata">
												<xsl:value-of select="format-number(WartoscWyplat, '# ##0,00', 'pl')"/>
											</td>
										</tr>
										<tr>
											<td>liczba osób</td>
											<td class="xmldata">
												<xsl:value-of select="LiczbaOsob"/>
											</td>
										</tr>
										</xsl:for-each>
										<xsl:for-each select="IKE">
										<tr>
											<td rowspan="2">IKE</td>
											<td>wartość wypłat</td>
											<td class="xmldata">
												<xsl:value-of select="format-number(WartoscWyplat, '# ##0,00', 'pl')"/>
											</td>
										</tr>
										<tr>
											<td>liczba osób</td>
											<td class="xmldata">
												<xsl:value-of select="LiczbaOsob"/>
											</td>
										</tr>
										</xsl:for-each>
										</xsl:for-each>
										</xsl:for-each>
										<xsl:for-each select="Jednorazowe">
										<tr>
											<td rowspan="2">jednorazowe</td>
											<td>wartość wypłat</td>
											<td class="xmldata">
												<xsl:value-of select="format-number(WartoscWyplat, '# ##0,00', 'pl')"/>
											</td>
										</tr>
										<tr>
											<td>liczba osób</td>
											<td class="xmldata">
												<xsl:value-of select="LiczbaOsob"/>
											</td>
										</tr>
										</xsl:for-each>
										<xsl:for-each select="Ratalne">
										<tr>
											<td rowspan="2">ratalne</td>
											<td>wartość wypłat</td>
											<td class="xmldata">
												<xsl:value-of select="format-number(WartoscWyplat, '# ##0,00', 'pl')"/>
											</td>
										</tr>
										<tr>
											<td>liczba osób</td>
											<td class="xmldata">
												<xsl:value-of select="LiczbaOsob"/>
											</td>
										</tr>
										</xsl:for-each>
										</xsl:for-each>
									</tbody>
								</table>
								</xsl:for-each>
								<br/>
							</xsl:for-each>
							<br/>
						</xsl:for-each>
						<br/>
					</xsl:for-each>
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
